package detail

import (
	"dbackup/logging"
	"github.com/kardianos/service"
	"github.com/robfig/cron"
	"os"
	"time"
)

func InitLogger() {
	_ = log.Init(&log.Logger{
		FileName: os.TempDir() + "/dbackup.log",
		RollSize: 1 << 30,
		RollInterval: time.Hour * 30,
		Level: log.DEBUG,
		PanicOnFatal: false,
	})
}


type Job interface {
	AddTask(*Task) error
}

type Task struct {
	Ch chan struct{}
	Cron *cron.Cron
}

func (t *Task) Start(srv service.Service) error {
	return nil
}

func (t* Task) Run() {

	t.Cron.Start()
	<- t.Ch
	log.Info("stopped")
	t.Cron.Stop()

}

func (t *Task) Stop(srv service.Service) error {
	log.Info("stopping...")
	t.Ch <- struct{}{}
	return nil
}

func (t *Task) AddTask(task Job) error {
	return task.AddTask(t)
}