package detail

import (
	log "dbackup/logging"
	"fmt"
	"github.com/robfig/cron"
	"os/exec"
	"strings"
	"time"
)

const (
	PGDumpCmd = "pg_dump"
)

type PGConfig struct {
	Host string
	Port string
	DB string
	Username string
	Password string
	Destination string
	Keep int
	Cron string
	Options []string
}

type Postgres struct {
	PGConfig []PGConfig
}

func (x *Postgres) AddTask(t *Task) error {
	for _, cfg := range x.PGConfig {
		if e := cfg.AddCron(t.Cron); e != nil {
			return e
		}
	}
	return nil
}

func (x *PGConfig) Run() {
	path := fmt.Sprintf(`%s/%v_%v.dump`, x.Destination, x.DB, time.Now().Unix())
	options := append(x.GetOptions(), "-Fc", fmt.Sprintf(`-f%v`, path))
	out, err := exec.Command(PGDumpCmd, options...).Output()
	if err != nil {
		log.Fatal("%s", out)
	} else {
		log.Info("%s %s, ok", PGDumpCmd, strings.Join(options, " "))
	}
}

func (x *PGConfig) AddCron(c *cron.Cron) error {
	s := strings.Split(x.Cron, " ")
	i := 0
	for j := 0; j < len(s); j++ {
		if len(strings.TrimSpace(s[j])) != 0 {
			s[i] = s[j]
			i += 1
		}
	}
	s = s[0:i]
	if len(s) != 5 {
		return fmt.Errorf("invalid cron format: %s", x.Cron)
	}
	return c.AddJob(strings.Join(s, " "), x)
}

func (x *PGConfig) GetOptions() []string {
	options := x.Options

	if x.DB != "" {
		options = append(options, fmt.Sprintf(`-d%v`, x.DB))
	}

	if x.Host != "" {
		options = append(options, fmt.Sprintf(`-h%v`, x.Host))
	}

	if x.Port != "" {
		options = append(options, fmt.Sprintf(`-p%v`, x.Port))
	}

	if x.Username != "" {
		options = append(options, fmt.Sprintf(`-U%v`, x.Username))
	}

	return options
}