// +build windows

package main

import (
	"dbackup/detail"
	"flag"
	"fmt"
	"github.com/kardianos/service"
	"github.com/robfig/cron"
	"log"
	"os"
	"path"
	"runtime"
)

func main() {
	svcFlag := flag.String("service", "", "Control the system service.")
	flag.Parse()

	p := &detail.Task{
		Ch: make(chan struct{}),
		Cron: cron.New(),
	}

	addTask(p)

	detail.InitLogger()

	s, e := service.New(p, &service.Config{
		Name:        "test",
		DisplayName: "test service",
		Description: "+1s",
	})

	if e != nil {
		log.Fatal(e)
	}

	errs := make(chan error, 5)
	lgg, e := s.Logger(errs)
	if e != nil {
		log.Fatal(e)
	}

	go func() {
		for {
			err := <-errs
			if err != nil {
				log.Print(err)
			}
		}
	}()

	if len(*svcFlag) != 0 {
		err := service.Control(s, *svcFlag)
		if err != nil {
			log.Printf("Valid actions: %q\n", service.ControlAction)
			log.Fatal(err)
		}
		return
	}

	e = s.Run()

	if e != nil {
		lgg.Error(e)
	}
}

func addTask(t *detail.Task) {
	bindir := []byte(path.Dir(os.Args[0]))
	if runtime.GOOS == "windows" {
		i := 0
		for j := 0; j < len(bindir); j++ {
			if bindir[j] != '\\' {
				bindir[i] = bindir[j]
				i += 1
			}
		}
		bindir = bindir[0:i]
	}

	cfg := fmt.Sprintf("%s/conf.toml", string(bindir))


}